<?php

namespace Drupal\elementor\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
use Drupal\Core\Language\LanguageManagerInterface;
use Drupal\Core\Routing\RouteMatchInterface;
use Drupal\Core\Template\TwigEnvironment;
use Drupal\elementor\ElementorPlugin;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;

/**
 * The class to generate elementor controller.
 */
class ElementorController extends ControllerBase implements ContainerInjectionInterface {

  /**
   * Variable to access elementor plugin
   *
   * @var \Drupal\elementor\ElementorPlugin
   */
  protected $elementorPlugin;

  /**
   * Variable to attach twig.
   *
   * @var \Drupal\Core\Template\TwigEnvironment
   */
  protected $twig;

  /**
   * The current route match.
   *
   * @var \Drupal\Core\Routing\RouteMatchInterface
   */
  protected $routeMatch;

  /**
   * The language manager service.
   *
   * @var \Drupal\Core\Language\LanguageManagerInterface
   */
  protected $languageManager;

  /**
   * {@inheritdoc}
   */
  public function __construct(ElementorPlugin $elementor_plugin, TwigEnvironment $twig, RouteMatchInterface $route_match, LanguageManagerInterface $language_manager) {
    $this->elementorPlugin = $elementor_plugin;
    $this->twig = $twig;
    $this->routeMatch = $route_match;
    $this->languageManager = $language_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
        $container->get('elementor.drupal'),
        $container->get('twig'),
        $container->get('current_route_match'),
        $container->get('language_manager')
      );
  }

  /**
   * Callback function for autosaving.
   */
  public function autosave(Request $request) {
    return new Response('', Response::HTTP_NOT_FOUND);
  }

  /**
   * Callback function for updating.
   */
  public function update(Request $request) {
    $return_data = $this->elementorPlugin->update($request);
    return new JsonResponse($return_data);
  }

  /**
   * Callback function to generate editor.
   */
  public function editor(Request $request) {
    $id = $this->routeMatch->getParameter('node');
    $editor_data = $this->elementorPlugin->editor($id);

    $template = $this->twig->loadTemplate(drupal_get_path('module', 'elementor') . '/templates/elementor-editor.html.twig');

    $dir = $this->languageManager->getCurrentLanguage()->getDirection();

    $html = $template->render([
      'is_rtl' => $dir == 'rtl',
      'elementor_data' => $editor_data,
      'base_path' => base_path() . drupal_get_path('module', 'elementor'),
    ]);

    $response = new Response();
    $response->setContent($html);

    return $response;
  }

  /**
   * Callback function to handle uploads.
   */
  public function upload(Request $request) {
    $files = [];
    foreach ($request->files->all() as $file) {
      $files[] = $this->elementorPlugin->sdk->upload_file($file->getPathName(), $file->getClientOriginalName());
    }
    return new JsonResponse($files);
  }

  /**
   * Callback function for deleting upload.
   */
  public function deletepload(Request $request) {
    $newFile = $this->elementorPlugin->sdk->delete_file($request->get('fid'));
    return new JsonResponse();
  }

}
